#
# spec file for package cxxopts
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cxxopts
Version:        3.2.1
Release:        1.1
Summary:        C++ command line option parser
License:        MIT
URL:            https://github.com/jarro2783/cxxopts
Source0:        https://github.com/jarro2783/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake

%description
CXXOpts is a C++ option parser library supporting some of the
GNU-style syntax for options.

%package devel
Summary:        Development files for %{name}
Requires:       libstdc++-devel

%description devel
CXXOpts is a C++ option parser library supporting single-letter options
with a single dash, and long options with a double-dash.
(There are some corner cases in 3.0.0 where behavior is not exactly
matching GNU getopt or POSIX mode.)
It requires and makes use of C++11 <regex>.

%prep
%autosetup -p1

%build
%cmake \
   -DCXXOPTS_BUILD_EXAMPLES:BOOL=oFF \
   -DCXXOPTS_BUILD_TESTS:BOOL=ON
%cmake_build

%install
%cmake_install

%check
%ctest

%files devel
%doc README.md
%license LICENSE
%{_includedir}/%{name}.hpp
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * Fix compilation with optional on C++20.
  * Fix unannotated fallthrough.
  * Fix sign conversion with Unicode output.
  * Don't initialize regex in static initialiser.
  * Fix incorrect integer overflow checks.
  * Change quote output to '' to match Windows.
  * Don't split positional arguments by the list delimiter.
  * Order help groups by the order they were added.
* Fri Apr  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.1:
  * Fixed version number in header.
  * Support for multiple long names for the same option (=
    multiple long aliases)
  * Add a `program()` function to retrieve the program name.
  * Added a .clang-format file.
  * Added iterator and printing for a ParseResult.
  * Cleanup exception code, add cxxopts::exceptions namespace.
  * Fix `arguments()` having no key for options that only have a
    short name.
* Fri Oct 14 2022 Jan Engelhardt <jengelh@inai.de>
- Update descriptions with limitations.
- Trim macros from URL: line (for copy-pasting with mouse).
* Sat Dec  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v3.0.0)
